@@ -279,17 +279,17 @@ def analyze_text(text, morphology=None, topic=None):
                 pass
             elif morphology:
                 logger.debug('checking "%s" by morphology', w)
-                skip = set([w])
+                stop = False
                 for parse in morphology(w):
+                    if stop:
+                        break
                     for lexeme in parse.lexeme:
                         variant_word = lexeme.word
-                        if variant_word in skip:
-                            continue
                         if variant_word in words:
                             morph.add(variant_word)
-                            skip.add(variant_word)
                             found += 1
                             logger.debug('word "%s" in words', variant_word)
+                            stop = True
                             break
 
         if found == len(coverwords):
