@@ -8,7 +8,7 @@ from django.core.exceptions import ValidationError
 from django.utils.translation import gettext_lazy as _
 
 from textrank.analyzer import analyze_text
-from textrank.models import Group, Keyword, Weight, Sample
+from textrank.models import Group, Keyword, Weight, Sample, Topic
 from textrank.validators import keyword_validator
 
 
@@ -93,16 +93,25 @@ class RankForm(forms.Form):
     text = forms.CharField(label=_('Текст'), widget=forms.Textarea())
     verbose = forms.BooleanField(
         required=False, initial=True, label=_('Подробно'))
+    topic = forms.ModelChoiceField(
+        required=False, label=_('Раздел'),
+        queryset=Topic.objects.filter(is_active=True),
+        to_field_name='code',
+        empty_label=_('Основной'),
+    )
     result = None
 
     def analyze(self):
         cdata = self.cleaned_data
-        result = analyze_text(cdata['text'])
+        result = analyze_text(cdata['text'], topic=cdata['topic'])
         if not cdata['verbose']:
             result.pop('words')
             result.pop('morph')
             result.pop('other')
             result.pop('utime')
+            # topic = result.pop('topic')
+            # if topic:
+            #     result['topic'] = '%(code)s :: %(name)s' % topic
         self.result = result
 
     def clean(self):
@@ -168,3 +177,10 @@ class RegForm(forms.Form):
                 weight.last_editor = user
                 weight.save()
         return keyword
+
+
+class TopicForm(LastEditorMixin, forms.ModelForm):
+
+    class Meta:
+        model = Topic
+        exclude = []
