@@ -1,5 +1,6 @@
 from textrank.views.pages import (
     IndexView, GroupsView, KeywordsView, RankView, WeightFormView, SamplesView,
+    TopicsView
 )
 
 index = IndexView.as_view()
@@ -8,3 +9,4 @@ keywords = KeywordsView.as_view()
 rank = RankView.as_view()
 weightform = WeightFormView.as_view()
 samples = SamplesView.as_view()
+topics = TopicsView.as_view()
